==> invite-2.0.x-dev.tar.gz: invite/src/Controller/InviteList.php <==
<?php

namespace Drupal\invite\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Database\Connection;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Url;
use Drupal\invite\InviteConstants;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Active user list controller.
 */
class InviteList extends ControllerBase {

  /**
   * Drupal\Core\Database\Driver\mysql\Connection definition.
   *
   * @var \Drupal\Core\Database\Driver\mysql\Connection
   */
  protected $database;

  /**
   * An array that contains invite status and related user readable name.
   *
   * @var array
   */
  public $inviteStatus;

  /**
   * A module manager object.
   *
   * @var \Drupal\Core\Extension\ModuleHandlerInterface
   */
  protected $moduleHandler;

  /**
   * Constructs a new InviteList object.
   *
   * @param \Drupal\Core\Database\Connection $database
   *   Connection database.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   Module handler interface.
   */
  public function __construct(Connection $database, ModuleHandlerInterface $module_handler) {
    $this->database = $database;
    $this->moduleHandler = $module_handler;
    $this->inviteStatus = [
      InviteConstants::INVITE_VALID => $this->t('Active'),
      InviteConstants::INVITE_WITHDRAWN => $this->t('Withdrawn'),
      InviteConstants::INVITE_USED => $this->t('Used'),
      InviteConstants::INVITE_EXPIRED => $this->t('Expired'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('database'),
      $container->get('module_handler')
    );
  }

  /**
   * Returns the active user list output.
   *
   * @return array
   *   A renderable array.
   */
  public function view() {

    $header = [
      ['data' => $this->t('Status')],
      ['data' => $this->t('Sender')],
      ['data' => $this->t('E-mail')],
      ['data' => $this->t('Operations')],
    ];

    $query = $this->database->select('invite', 'i');
    $query->fields('ufd', ['mail']);
    $query->fields('i', ['id', 'status']);
    $query->leftJoin('users', 'u', 'i.user_id = u.uid');
    $query->leftJoin('users_field_data', 'ufd', 'u.uid = ufd.uid');
    if ($this->moduleHandler->moduleExists('invite_by_email')) {
      $query->fields('ie', ['field_invite_email_address_value']);
      $query->leftJoin('invite__field_invite_email_address', 'ie', 'i.id = ie.entity_id');
    }
    $query->orderBy('i.id', 'desc');

    $query = $query->extend('Drupal\Core\Database\Query\PagerSelectExtender');
    $query->limit(20);
    $result = $query->execute();

    $rows = [];
    foreach ($result as $row) {
      $operations = [
        '#type' => 'operations',
        '#links' => $this->getOperations($row->id),
        '#attributes' => [],
      ];
      $rows[] = [
        'data' => [
          'status' => $this->inviteStatus[$row->status],
          'mail' => $row->mail,
          'field_invite_email_address_value' => $row->field_invite_email_address_value,
          'operations' => render($operations),
        ],
      ];
    }

    $output['table'] = [
      '#theme' => 'table',
      '#header' => $header,
      '#rows' => $rows,
    ];

    $output['pager'] = [
      '#type' => 'pager',
    ];

    return $output;
  }

  /**
   * Get operations links like withdraw and resend invitation.
   *
   * @param int $invitation_id
   *   Invite entity id (invite id).
   *
   * @return array
   *   Array of withdraw and resend links.
   */
  public function getOperations($invitation_id) {
    $links[] = [
      'title' => $this->t('Withdraw'),
      'url' => Url::fromRoute('invite.invite_withdraw_form',
        ['invite' => $invitation_id]
      ),
    ];
    $links[] = [
      'title' => $this->t('Resend'),
      'url' => Url::fromRoute('invite.invite_resend_form',
        ['invite' => $invitation_id]
      ),
    ];
    return $links;
  }

}

==> invite-3.0.x-dev.tar.gz: invite/src/Controller/InviteList.php <==
<?php

namespace Drupal\invite\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Database\Connection;
use Drupal\Core\Database\Query\PagerSelectExtender;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Render\RendererInterface;
use Drupal\Core\Url;
use Drupal\invite\InviteConstants;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Active user list controller.
 */
class InviteList extends ControllerBase {

  /**
   * Drupal\Core\Database\Driver\mysql\Connection definition.
   *
   * @var \Drupal\Core\Database\Driver\mysql\Connection
   */
  protected $database;

  /**
   * An array that contains invite status and related user readable name.
   *
   * @var array
   */
  public $inviteStatus;

  /**
   * A module manager object.
   *
   * @var \Drupal\Core\Extension\ModuleHandlerInterface
   */
  protected $moduleHandler;

  /**
   * A module manager object.
   *
   * @var \Drupal\Core\Render\RendererInterface
   */
  protected $renderer;

  /**
   * Constructs a new InviteList object.
   *
   * @param \Drupal\Core\Database\Connection $database
   *   Connection database.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   Module handler interface.
   * @param \Drupal\Core\Render\RendererInterface $renderer
   *   Renderer interface.
   */
  public function __construct(Connection $database, ModuleHandlerInterface $module_handler, RendererInterface $renderer) {
    $this->database = $database;
    $this->moduleHandler = $module_handler;
    $this->renderer = $renderer;
    $this->inviteStatus = [
      InviteConstants::INVITE_VALID => $this->t('Active'),
      InviteConstants::INVITE_WITHDRAWN => $this->t('Withdrawn'),
      InviteConstants::INVITE_USED => $this->t('Used'),
      InviteConstants::INVITE_EXPIRED => $this->t('Expired'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('database'),
      $container->get('module_handler'),
      $container->get('renderer')
    );
  }

  /**
   * Returns the active user list output.
   *
   * @return array
   *   A renderable array.
   */
  public function view() {

    $header = [
      ['data' => $this->t('Status')],
      ['data' => $this->t('Sender')],
      ['data' => $this->t('E-mail')],
      ['data' => $this->t('Operations')],
    ];

    /** @var \Drupal\Core\Database\Query\SelectInterface $query */
    $query = $this->database->select('invite', 'i');
    $query->fields('ufd', ['mail']);
    $query->fields('i', ['id', 'status']);
    $query->leftJoin('users', 'u', 'i.user_id = u.uid');
    $query->leftJoin('users_field_data', 'ufd', 'u.uid = ufd.uid');
    if ($this->moduleHandler->moduleExists('invite_by_email')) {
      $query->fields('ie', ['field_invite_email_address_value']);
      $query->leftJoin('invite__field_invite_email_address', 'ie', 'i.id = ie.entity_id');
    }
    $query->orderBy('i.id', 'desc');
    $selectExtender = $query->extend(PagerSelectExtender::class);

    /** @var \Drupal\Core\Database\Query\PagerSelectExtender $selectExtender */
    $selectExtender->limit(20);
    $result = $selectExtender->execute();

    $rows = [];
    foreach ($result as $row) {
      $operations = [
        '#type' => 'operations',
        '#links' => $this->getOperations($row->id),
        '#attributes' => [],
      ];
      $rows[] = [
        'data' => [
          'status' => $this->inviteStatus[$row->status],
          'mail' => $row->mail,
          'field_invite_email_address_value' => $row->field_invite_email_address_value,
          'operations' => $this->renderer->render($operations),
        ],
      ];
    }

    $output['table'] = [
      '#theme' => 'table',
      '#header' => $header,
      '#rows' => $rows,
    ];

    $output['pager'] = [
      '#type' => 'pager',
    ];

    return $output;
  }

  /**
   * Get operations links like withdraw and resend invitation.
   *
   * @param int $invitation_id
   *   Invite entity id (invite id).
   *
   * @return array
   *   Array of withdraw and resend links.
   */
  public function getOperations($invitation_id) {
    $links[] = [
      'title' => $this->t('Withdraw'),
      'url' => Url::fromRoute('invite.invite_withdraw_form',
        ['invite' => $invitation_id]
      ),
    ];
    $links[] = [
      'title' => $this->t('Resend'),
      'url' => Url::fromRoute('invite.invite_resend_form',
        ['invite' => $invitation_id]
      ),
    ];
    return $links;
  }

}
